@@ -5,7 +5,7 @@ Created on 14-5-7
 
 @author: tufei
 @description:
-         
+
 Copyright (c) 2013 infohold inc. All rights reserved.
 """
 import inspect
@@ -179,15 +179,15 @@ class CacheName(object):
             return ns, ns
 
     @classmethod
-    def get_by_function_and_ns(cls, ns, func, *func_args, **func_kwargs):
-        """根据指定的ns和func的参数来生成缓存key名
+    def get_by_ns(cls, ns, func_type, *func_args, **func_kwargs):
+        """根据指定的ns和func的type的参数来生成缓存key名
         :param ns: 指定的名字空间（前缀）
-        :param func: 函数对象
+        :param func_type: 函数对象类型
         :param func_args: 函数位置参数
         :param func_kwargs: 函数关键字参数
         :return: string -- 缓存key名
         """
-        args_key = cls.get_func_args_key(cls.get_func_type(func), *func_args, **func_kwargs)
+        args_key = cls.get_func_args_key(func_type, *func_args, **func_kwargs)
         return "%s:%s" % (ns, args_key) if args_key else ns
 
 
@@ -195,6 +195,12 @@ CACHE_GET = 1
 CACHE_DELETE = 2
 
 
+def _cache_delete(name, cache_inst, func_type, *args, **kwargs):
+    ns = cache_inst.get("cache:alias:%s" % name)
+    cache_key = CacheName.get_by_ns(ns, func_type, *args, **kwargs)
+    cache_inst.delete(cache_key)
+
+
 def cacheable(name=None, expire=300, action=CACHE_GET, cache_cls=RedisCache):
     def _cacheable(func):
         @functools.wraps(func)
@@ -216,9 +222,39 @@ def cacheable(name=None, expire=300, action=CACHE_GET, cache_cls=RedisCache):
             elif action == CACHE_DELETE:
                 result = func(*args, **kwargs)
                 if name is not None:
-                    ns = cache.get("cache:alias:%s" % name)
-                    cache_key = CacheName.get_by_function_and_ns(ns, func, *args, **kwargs)
-                    cache.delete(cache_key)
+                    _cache_delete(name, cache, CacheName.get_func_type(func), *args, **kwargs)
                 return result
         return wrapper
     return _cacheable
+
+
+def cache_delete(name, cache_cls=RedisCache, *args, **kwargs):
+    """删除对象缓存
+    :param name: 缓存别名
+    :param cache_cls: 缓存实现类
+    :param args: 缓存Key位置参数，需要参考cacheable修饰的函数方法的位置参数
+    :param kwargs: 缓存Key关键字参数，需要参考cacheable修饰的函数方法的关键字参数
+    :return: None
+
+    示例：
+    @cacheable(name="object_name")
+    def get_object(id):
+        # do something, eg. return new object instance by given id
+        pass
+
+    def update_object(obj):
+        # do something, eg, update a object
+
+        @cacheable(name="object_name", action=CACHE_DELETE)
+        def del_cache(id):
+            pass
+        del_cache(obj.id)
+
+    def update_object_ex(obj):
+        # do something, eg, update a object instance
+        delete_cache("object_name", obj.id)
+
+    function update_object() equivalent to function update_object_ex()
+    """
+    cache = cache_cls()
+    return _cache_delete(name, cache, CacheName.TYPE_GEN_METHOD, *args, **kwargs)
\ No newline at end of file
